@@ -17,18 +17,20 @@
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
+#include <sys/types.h>
+#include <unistd.h>
 
 #include "kio_tvshow.h"
 
-#include <Nepomuk/ResourceManager>
-#include <Nepomuk/Vocabulary/NMM>
-#include <Nepomuk/Vocabulary/NIE>
-#include <Nepomuk/Vocabulary/NFO>
-#include <Nepomuk/Query/FileQuery>
-#include <Nepomuk/Query/ComparisonTerm>
-#include <Nepomuk/Query/ResourceTypeTerm>
-#include <Nepomuk/Query/LiteralTerm>
-#include <Nepomuk/Query/AndTerm>
+#include <Nepomuk2/ResourceManager>
+#include <Nepomuk2/Vocabulary/NMM>
+#include <Nepomuk2/Vocabulary/NIE>
+#include <Nepomuk2/Vocabulary/NFO>
+#include <Nepomuk2/Query/FileQuery>
+#include <Nepomuk2/Query/ComparisonTerm>
+#include <Nepomuk2/Query/ResourceTypeTerm>
+#include <Nepomuk2/Query/LiteralTerm>
+#include <Nepomuk2/Query/AndTerm>
 
 #include <KUrl>
 #include <kio/global.h>
@@ -50,7 +52,7 @@
 #include <QStringList>
 
 using namespace KIO;
-using namespace Nepomuk::Vocabulary;
+using namespace Nepomuk2::Vocabulary;
 using namespace Soprano::Vocabulary;
 
 
@@ -85,24 +87,24 @@ namespace {
 }
 
 
-Nepomuk::TvshowProtocol::TvshowProtocol( const QByteArray& poolSocket, const QByteArray& appSocket )
+Nepomuk2::TvshowProtocol::TvshowProtocol( const QByteArray& poolSocket, const QByteArray& appSocket )
     : KIO::SlaveBase( "tvshow", poolSocket, appSocket )
 {
 }
 
 
-Nepomuk::TvshowProtocol::~TvshowProtocol()
+Nepomuk2::TvshowProtocol::~TvshowProtocol()
 {
 }
 
 
-void Nepomuk::TvshowProtocol::listDir( const KUrl& url )
+void Nepomuk2::TvshowProtocol::listDir( const KUrl& url )
 {
     // root folder
     if(url.path().length() <= 1) {
         // list all tv shows including title, description, and an optional depiction (for now we simply take one of them)
         Soprano::QueryResultIterator it
-                = Nepomuk::ResourceManager::instance()->mainModel()->executeQuery(QString::fromLatin1("select distinct ?r ?t ?d where { "
+                = Nepomuk2::ResourceManager::instance()->mainModel()->executeQuery(QString::fromLatin1("select distinct ?r ?t ?d where { "
                                                                                                       "?r a %1 . "
                                                                                                       "?r %2 ?t . "
                                                                                                       "?r %3 ?d . "
@@ -123,6 +125,11 @@ void Nepomuk::TvshowProtocol::listDir( const KUrl& url )
                                                 it["md"].literal().toDateTime());
             listEntry(uds, false);
         }
+
+        KIO::UDSEntry uds = createFolderUDSEntry(QLatin1String("latest"), i18n("Next Episodes To Watch"));
+        uds.insert(KIO::UDSEntry::UDS_ICON_NAME, QLatin1String("favorites"));
+        listEntry(uds, false);
+
         listEntry(UDSEntry(), true);
         finished();
     }
@@ -130,28 +137,97 @@ void Nepomuk::TvshowProtocol::listDir( const KUrl& url )
     // all other URLS
     else {
         const QStringList pathTokens = url.path().split('/', QString::SkipEmptyParts);
+        if(pathTokens.count() == 1 && pathTokens.first() == QLatin1String("latest")) {
+            // list the next unwatched episodes of all series
+            // query the min episode which does not have any watched episode after it
+            // TODO: find a way to also query the episode at the same time
+            Soprano::QueryResultIterator it
+                    = Nepomuk2::ResourceManager::instance()->mainModel()->executeQuery(QLatin1String("select ?st ?series min(1000*?s+?e) as ?x where { "
+                                                                                                    "?r a nmm:TVShow ; "
+                                                                                                    "nmm:episodeNumber ?e ; "
+                                                                                                    "nmm:season ?s ; "
+                                                                                                    "nmm:series ?series . "
+                                                                                                    "?series nie:title ?st "
+                                                                                                    "FILTER NOT EXISTS { ?r nuao:usageCount ?u . filter(?u>0) . } "
+                                                                                                    "FILTER NOT EXISTS { "
+                                                                                                    "?r2 a nmm:TVShow ; "
+                                                                                                    "nmm:series ?series ; "
+                                                                                                    "nmm:episodeNumber ?e2 ; "
+                                                                                                    "nmm:season ?s2 ; "
+                                                                                                    "nuao:usageCount ?uc . "
+                                                                                                    "filter(?uc>0) . "
+                                                                                                    "filter((1000*?s2+?e2) > (1000*?s+?e)) . } "
+                                                                                                    "}"),
+                                                                                      Soprano::Query::QueryLanguageSparql);
+            while(it.next()) {
+                const QString seriesTitle = it["st"].toString();
+                const int seasonNum = it["x"].literal().toInt() / 1000;
+                const int episodeNum = it["x"].literal().toInt() % 1000;
+                Soprano::QueryResultIterator it2
+                        = Nepomuk2::ResourceManager::instance()->mainModel()->executeQuery(QString::fromLatin1("select ?r ?url ?t where { "
+                                                                                                              "?r a nmm:TVShow ; "
+                                                                                                              "nie:url ?url ; "
+                                                                                                              "nie:title ?t ; "
+                                                                                                              "nmm:series %1 ; "
+                                                                                                              "nmm:episodeNumber %2 ; "
+                                                                                                              "nmm:season %3 . "
+                                                                                                              "OPTIONAL { ?r nmm:releaseDate ?rd ; "
+                                                                                                              "nmm:synopsis ?d . } . }")
+                                                                                          .arg(it["series"].toN3())
+                                                                                          .arg(episodeNum)
+                                                                                          .arg(seasonNum),
+                                                                                          Soprano::Query::QueryLanguageSparql);
+                if(it2.next()) {
+                    const QString episodeTitle = it2["t"].toString();
+                    const QString title = i18n("Next episode of %1: %2x%3 - %4",
+                                               seriesTitle,
+                                               QString::number(seasonNum).rightJustified(2, QLatin1Char('0')),
+                                               QString::number(episodeNum).rightJustified(2, QLatin1Char('0')),
+                                               episodeTitle);
+                    UDSEntry uds;
+                    uds.insert( KIO::UDSEntry::UDS_NAME, title );
+                    uds.insert( KIO::UDSEntry::UDS_FILE_TYPE, S_IFREG );
+                    uds.insert( KIO::UDSEntry::UDS_DISPLAY_TYPE, i18n("TV Show") );
+                    uds.insert( KIO::UDSEntry::UDS_ACCESS, 0700 );
+                    uds.insert( KIO::UDSEntry::UDS_USER, KUser().loginName() );
+                    uds.insert( KIO::UDSEntry::UDS_CREATION_TIME, it2["rd"].literal().toDateTime().toTime_t() );
+                    uds.insert( KIO::UDSEntry::UDS_COMMENT, it2["d"].toString() );
+                    uds.insert( KIO::UDSEntry::UDS_URL, KUrl(it2["url"].uri()).url() );
+                    uds.insert( KIO::UDSEntry::UDS_NEPOMUK_URI, KUrl(it2["r"].uri()).url() );
+                    listEntry(uds, false);
+                }
+            }
+            listEntry(UDSEntry(), true);
+            finished();
+        }
+
         if(pathTokens.count() == 1) {
             // list one TV Series: list seasons
             Soprano::QueryResultIterator it
-                    = Nepomuk::ResourceManager::instance()->mainModel()->executeQuery(QString::fromLatin1("select distinct ?s where { "
+                    = Nepomuk2::ResourceManager::instance()->mainModel()->executeQuery(QString::fromLatin1("select distinct ?s where { "
                                                                                                           "?r nmm:series ?tv . "
                                                                                                           "?tv nie:title %1 . "
-                                                                                                          "?r nmm:season ?s . }")
+                                                                                                          "?r nmm:season ?s . "
+                                                                                                          "OPTIONAL { ?sr a nmm:TVSeason ; nmm:seasonOf ?tv ; nmm:seasonNumber ?s . } . }")
                                                                                       .arg(Soprano::Node::literalToN3(pathTokens.first())),
                                                                                       Soprano::Query::QueryLanguageSparql);
             while(it.next()) {
                 const QString name = pathTokens.first() + QLatin1String(" - ") + i18n("Season %1", it["s"].literal().toInt());
                 UDSEntry uds = createFolderUDSEntry(name, name);
+                if(it["sr"].isResource()) {
+                    uds.insert( KIO::UDSEntry::UDS_NEPOMUK_URI, KUrl(it["sr"].uri()).url() );
+                }
                 listEntry(uds, false);
             }
             listEntry(UDSEntry(), true);
             finished();
         }
+
         else if(pathTokens.count() == 2) {
             const QString seriesTitle = pathTokens[0];
             const int season = pathTokens[1].mid(pathTokens[1].lastIndexOf(' ')+1).toInt();
             Soprano::QueryResultIterator it
-                    = Nepomuk::ResourceManager::instance()->mainModel()->executeQuery(QString::fromLatin1("select distinct * where { "
+                    = Nepomuk2::ResourceManager::instance()->mainModel()->executeQuery(QString::fromLatin1("select distinct * where { "
                                                                                                           "?r a nmm:TVShow ; "
                                                                                                           "nmm:season %1 ; "
                                                                                                           "nmm:series [ nie:title %2 ] ; "
@@ -174,11 +250,13 @@ void Nepomuk::TvshowProtocol::listDir( const KUrl& url )
                 uds.insert( KIO::UDSEntry::UDS_CREATION_TIME, it["rd"].literal().toDateTime().toTime_t() );
                 uds.insert( KIO::UDSEntry::UDS_COMMENT, it["d"].toString() );
                 uds.insert( KIO::UDSEntry::UDS_URL, KUrl(it["url"].uri()).url() );
+                uds.insert( KIO::UDSEntry::UDS_NEPOMUK_URI, KUrl(it["r"].uri()).url() );
                 listEntry(uds, false);
             }
             listEntry(UDSEntry(), true);
             finished();
         }
+
         else {
             error( KIO::ERR_CANNOT_ENTER_DIRECTORY, url.prettyUrl() );
         }
@@ -186,20 +264,20 @@ void Nepomuk::TvshowProtocol::listDir( const KUrl& url )
 }
 
 
-void Nepomuk::TvshowProtocol::mkdir( const KUrl &url, int permissions )
+void Nepomuk2::TvshowProtocol::mkdir( const KUrl &url, int permissions )
 {
     Q_UNUSED(permissions);
     error( ERR_UNSUPPORTED_ACTION, url.prettyUrl() );
 }
 
 
-void Nepomuk::TvshowProtocol::get( const KUrl& url )
+void Nepomuk2::TvshowProtocol::get( const KUrl& url )
 {
     error( ERR_UNSUPPORTED_ACTION, url.prettyUrl() );
 }
 
 
-void Nepomuk::TvshowProtocol::put( const KUrl& url, int permissions, KIO::JobFlags flags )
+void Nepomuk2::TvshowProtocol::put( const KUrl& url, int permissions, KIO::JobFlags flags )
 {
     Q_UNUSED(permissions);
     Q_UNUSED(flags);
@@ -208,7 +286,7 @@ void Nepomuk::TvshowProtocol::put( const KUrl& url, int permissions, KIO::JobFla
 }
 
 
-void Nepomuk::TvshowProtocol::copy( const KUrl& src, const KUrl& dest, int permissions, KIO::JobFlags flags )
+void Nepomuk2::TvshowProtocol::copy( const KUrl& src, const KUrl& dest, int permissions, KIO::JobFlags flags )
 {
     Q_UNUSED(src);
     Q_UNUSED(dest);
@@ -219,7 +297,7 @@ void Nepomuk::TvshowProtocol::copy( const KUrl& src, const KUrl& dest, int permi
 }
 
 
-void Nepomuk::TvshowProtocol::rename( const KUrl& src, const KUrl& dest, KIO::JobFlags flags )
+void Nepomuk2::TvshowProtocol::rename( const KUrl& src, const KUrl& dest, KIO::JobFlags flags )
 {
     Q_UNUSED(src);
     Q_UNUSED(dest);
@@ -229,28 +307,35 @@ void Nepomuk::TvshowProtocol::rename( const KUrl& src, const KUrl& dest, KIO::Jo
 }
 
 
-void Nepomuk::TvshowProtocol::del( const KUrl& url, bool isfile )
+void Nepomuk2::TvshowProtocol::del( const KUrl& url, bool isfile )
 {
     Q_UNUSED(isfile);
     error( ERR_UNSUPPORTED_ACTION, url.prettyUrl() );
 }
 
 
-void Nepomuk::TvshowProtocol::mimetype( const KUrl& url )
+void Nepomuk2::TvshowProtocol::mimetype( const KUrl& url )
 {
     // FIXME
     error( ERR_UNSUPPORTED_ACTION, url.prettyUrl() );
 }
 
 
-void Nepomuk::TvshowProtocol::stat( const KUrl& url )
+void Nepomuk2::TvshowProtocol::stat( const KUrl& url )
 {
     // for basic functionality we only need to stat the folders
     const QStringList pathTokens = url.path().split('/', QString::SkipEmptyParts);
-    if(pathTokens.count() == 1) {
+    if(pathTokens.count() == 1 && pathTokens.first() == QLatin1String("latest")) {
+        KIO::UDSEntry uds = createFolderUDSEntry(QLatin1String("latest"), i18n("Next Episodes To Watch"));
+        uds.insert(KIO::UDSEntry::UDS_ICON_NAME, QLatin1String("favorites"));
+        statEntry(uds);
+        finished();
+    }
+
+    else if(pathTokens.count() == 1) {
         // stat series folder
         Soprano::QueryResultIterator it
-                = Nepomuk::ResourceManager::instance()->mainModel()->executeQuery(QString::fromLatin1("select distinct * where { "
+                = Nepomuk2::ResourceManager::instance()->mainModel()->executeQuery(QString::fromLatin1("select distinct * where { "
                                                                                                       "?r a nmm:TVSeries ; "
                                                                                                       "nie:title %1 ; "
                                                                                                       "nao:created ?cd ; "
@@ -271,11 +356,13 @@ void Nepomuk::TvshowProtocol::stat( const KUrl& url )
             error( ERR_DOES_NOT_EXIST, url.prettyUrl() );
         }
     }
+
     else if(pathTokens.count() == 2) {
         // stat season folder
         statEntry(createFolderUDSEntry(pathTokens[0], pathTokens[1]));
         finished();
     }
+
     else {
         // FIXME
         error( ERR_UNSUPPORTED_ACTION, url.prettyUrl() );
@@ -298,7 +385,7 @@ extern "C"
             exit(-1);
         }
 
-        Nepomuk::TvshowProtocol slave(argv[2], argv[3]);
+        Nepomuk2::TvshowProtocol slave(argv[2], argv[3]);
         slave.dispatchLoop();
 
         kDebug(7102) << "Tvshow slave Done";
