@@ -8,11 +8,11 @@
 #include <QtCore/QTime>
 #include <QtCore/QDateTime>
 
-#include <nepomuk/simpleresource.h>
+#include <nepomuk2/simpleresource.h>
 
 #include "nco/contactmedium.h"
 
-namespace Nepomuk {
+namespace Nepomuk2 {
 namespace NCO {
 /**
  * An account in an Instant Messaging system. 
@@ -35,36 +35,99 @@ public:
     }
 
     /**
-     * Get property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#requestedPresenceSubscriptionTo. 
-     * Indicates that this IMAccount has requested a subscription 
-     * to the presence information of the other IMAccount. 
+     * Get property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#publishesPresenceTo. 
+     * Indicates that this IMAccount publishes its presence information 
+     * to the other IMAccount. 
      */
-    QList<QUrl> requestedPresenceSubscriptionTos() const {
+    QList<QUrl> publishesPresenceTos() const {
         QList<QUrl> value;
-        foreach(const QVariant& v, property(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#requestedPresenceSubscriptionTo", QUrl::StrictMode)))
+        foreach(const QVariant& v, property(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#publishesPresenceTo", QUrl::StrictMode)))
             value << v.value<QUrl>();
         return value;
     }
 
     /**
-     * Set property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#requestedPresenceSubscriptionTo. 
-     * Indicates that this IMAccount has requested a subscription 
-     * to the presence information of the other IMAccount. 
+     * Set property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#publishesPresenceTo. 
+     * Indicates that this IMAccount publishes its presence information 
+     * to the other IMAccount. 
      */
-    void setRequestedPresenceSubscriptionTos(const QList<QUrl>& value) {
+    void setPublishesPresenceTos(const QList<QUrl>& value) {
         QVariantList values;
         foreach(const QUrl& v, value)
             values << v;
-        setProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#requestedPresenceSubscriptionTo", QUrl::StrictMode), values);
+        setProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#publishesPresenceTo", QUrl::StrictMode), values);
     }
 
     /**
-     * Add value to property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#requestedPresenceSubscriptionTo. 
-     * Indicates that this IMAccount has requested a subscription 
-     * to the presence information of the other IMAccount. 
+     * Add value to property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#publishesPresenceTo. 
+     * Indicates that this IMAccount publishes its presence information 
+     * to the other IMAccount. 
      */
-    void addRequestedPresenceSubscriptionTo(const QUrl& value) {
-        addProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#requestedPresenceSubscriptionTo", QUrl::StrictMode), value);
+    void addPublishesPresenceTo(const QUrl& value) {
+        addProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#publishesPresenceTo", QUrl::StrictMode), value);
+    }
+
+    /**
+     * Get property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#hasIMCapability. 
+     * Indicates that an IMAccount has a certain capability. 
+     */
+    QList<QUrl> iMCapabilitys() const {
+        QList<QUrl> value;
+        foreach(const QVariant& v, property(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#hasIMCapability", QUrl::StrictMode)))
+            value << v.value<QUrl>();
+        return value;
+    }
+
+    /**
+     * Set property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#hasIMCapability. 
+     * Indicates that an IMAccount has a certain capability. 
+     */
+    void setIMCapabilitys(const QList<QUrl>& value) {
+        QVariantList values;
+        foreach(const QUrl& v, value)
+            values << v;
+        setProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#hasIMCapability", QUrl::StrictMode), values);
+    }
+
+    /**
+     * Add value to property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#hasIMCapability. 
+     * Indicates that an IMAccount has a certain capability. 
+     */
+    void addIMCapability(const QUrl& value) {
+        addProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#hasIMCapability", QUrl::StrictMode), value);
+    }
+
+    /**
+     * Get property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#imID. 
+     * Identifier of the IM account. Examples of such identifier might 
+     * include ICQ UINs, Jabber IDs, Skype names etc. 
+     */
+    QStringList imIDs() const {
+        QStringList value;
+        foreach(const QVariant& v, property(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#imID", QUrl::StrictMode)))
+            value << v.value<QString>();
+        return value;
+    }
+
+    /**
+     * Set property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#imID. 
+     * Identifier of the IM account. Examples of such identifier might 
+     * include ICQ UINs, Jabber IDs, Skype names etc. 
+     */
+    void setImIDs(const QStringList& value) {
+        QVariantList values;
+        foreach(const QString& v, value)
+            values << v;
+        setProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#imID", QUrl::StrictMode), values);
+    }
+
+    /**
+     * Add value to property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#imID. 
+     * Identifier of the IM account. Examples of such identifier might 
+     * include ICQ UINs, Jabber IDs, Skype names etc. 
+     */
+    void addImID(const QString& value) {
+        addProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#imID", QUrl::StrictMode), value);
     }
 
     /**
@@ -97,102 +160,6 @@ public:
         addProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#imNickname", QUrl::StrictMode), value);
     }
 
-    /**
-     * Get property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#isBlocked. 
-     * Indicates that this IMAccount has been blocked. 
-     */
-    bool isBlocked() const {
-        bool value;
-        if(contains(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#isBlocked", QUrl::StrictMode)))
-            value = property(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#isBlocked", QUrl::StrictMode)).first().value<bool>();
-        return value;
-    }
-
-    /**
-     * Set property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#isBlocked. 
-     * Indicates that this IMAccount has been blocked. 
-     */
-    void setIsBlocked(const bool& value) {
-        QVariantList values;
-        values << value;
-        setProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#isBlocked", QUrl::StrictMode), values);
-    }
-
-    /**
-     * Add value to property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#isBlocked. 
-     * Indicates that this IMAccount has been blocked. 
-     */
-    void addIsBlocked(const bool& value) {
-        addProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#isBlocked", QUrl::StrictMode), value);
-    }
-
-    /**
-     * Get property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#imStatusMessage. 
-     * A feature common in most IM systems. A message left by the user 
-     * for all his/her contacts to see. 
-     */
-    QString imStatusMessage() const {
-        QString value;
-        if(contains(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#imStatusMessage", QUrl::StrictMode)))
-            value = property(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#imStatusMessage", QUrl::StrictMode)).first().value<QString>();
-        return value;
-    }
-
-    /**
-     * Set property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#imStatusMessage. 
-     * A feature common in most IM systems. A message left by the user 
-     * for all his/her contacts to see. 
-     */
-    void setImStatusMessage(const QString& value) {
-        QVariantList values;
-        values << value;
-        setProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#imStatusMessage", QUrl::StrictMode), values);
-    }
-
-    /**
-     * Add value to property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#imStatusMessage. 
-     * A feature common in most IM systems. A message left by the user 
-     * for all his/her contacts to see. 
-     */
-    void addImStatusMessage(const QString& value) {
-        addProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#imStatusMessage", QUrl::StrictMode), value);
-    }
-
-    /**
-     * Get property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#imAccountType. 
-     * Type of the IM account. This may be the name of the service that 
-     * provides the IM functionality. Examples might include Jabber, 
-     * ICQ, MSN etc 
-     */
-    QString imAccountType() const {
-        QString value;
-        if(contains(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#imAccountType", QUrl::StrictMode)))
-            value = property(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#imAccountType", QUrl::StrictMode)).first().value<QString>();
-        return value;
-    }
-
-    /**
-     * Set property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#imAccountType. 
-     * Type of the IM account. This may be the name of the service that 
-     * provides the IM functionality. Examples might include Jabber, 
-     * ICQ, MSN etc 
-     */
-    void setImAccountType(const QString& value) {
-        QVariantList values;
-        values << value;
-        setProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#imAccountType", QUrl::StrictMode), values);
-    }
-
-    /**
-     * Add value to property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#imAccountType. 
-     * Type of the IM account. This may be the name of the service that 
-     * provides the IM functionality. Examples might include Jabber, 
-     * ICQ, MSN etc 
-     */
-    void addImAccountType(const QString& value) {
-        addProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#imAccountType", QUrl::StrictMode), value);
-    }
-
     /**
      * Get property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#isAccessedBy. 
      * Indicates the local IMAccount by which this IMAccount is accessed. 
@@ -227,33 +194,67 @@ public:
     }
 
     /**
-     * Get property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#hasIMCapability. 
-     * Indicates that an IMAccount has a certain capability. 
+     * Get property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#isBlocked. 
+     * Indicates that this IMAccount has been blocked. 
      */
-    QList<QUrl> iMCapabilitys() const {
-        QList<QUrl> value;
-        foreach(const QVariant& v, property(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#hasIMCapability", QUrl::StrictMode)))
-            value << v.value<QUrl>();
+    bool isBlocked() const {
+        bool value;
+        if(contains(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#isBlocked", QUrl::StrictMode)))
+            value = property(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#isBlocked", QUrl::StrictMode)).first().value<bool>();
         return value;
     }
 
     /**
-     * Set property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#hasIMCapability. 
-     * Indicates that an IMAccount has a certain capability. 
+     * Set property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#isBlocked. 
+     * Indicates that this IMAccount has been blocked. 
      */
-    void setIMCapabilitys(const QList<QUrl>& value) {
+    void setIsBlocked(const bool& value) {
         QVariantList values;
-        foreach(const QUrl& v, value)
-            values << v;
-        setProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#hasIMCapability", QUrl::StrictMode), values);
+        values << value;
+        setProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#isBlocked", QUrl::StrictMode), values);
     }
 
     /**
-     * Add value to property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#hasIMCapability. 
-     * Indicates that an IMAccount has a certain capability. 
+     * Add value to property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#isBlocked. 
+     * Indicates that this IMAccount has been blocked. 
      */
-    void addIMCapability(const QUrl& value) {
-        addProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#hasIMCapability", QUrl::StrictMode), value);
+    void addIsBlocked(const bool& value) {
+        addProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#isBlocked", QUrl::StrictMode), value);
+    }
+
+    /**
+     * Get property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#imAccountType. 
+     * Type of the IM account. This may be the name of the service that 
+     * provides the IM functionality. Examples might include Jabber, 
+     * ICQ, MSN etc 
+     */
+    QString imAccountType() const {
+        QString value;
+        if(contains(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#imAccountType", QUrl::StrictMode)))
+            value = property(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#imAccountType", QUrl::StrictMode)).first().value<QString>();
+        return value;
+    }
+
+    /**
+     * Set property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#imAccountType. 
+     * Type of the IM account. This may be the name of the service that 
+     * provides the IM functionality. Examples might include Jabber, 
+     * ICQ, MSN etc 
+     */
+    void setImAccountType(const QString& value) {
+        QVariantList values;
+        values << value;
+        setProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#imAccountType", QUrl::StrictMode), values);
+    }
+
+    /**
+     * Add value to property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#imAccountType. 
+     * Type of the IM account. This may be the name of the service that 
+     * provides the IM functionality. Examples might include Jabber, 
+     * ICQ, MSN etc 
+     */
+    void addImAccountType(const QString& value) {
+        addProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#imAccountType", QUrl::StrictMode), value);
     }
 
     /**
@@ -310,36 +311,35 @@ public:
     }
 
     /**
-     * Get property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#publishesPresenceTo. 
-     * Indicates that this IMAccount publishes its presence information 
-     * to the other IMAccount. 
+     * Get property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#imStatusMessage. 
+     * A feature common in most IM systems. A message left by the user 
+     * for all his/her contacts to see. 
      */
-    QList<QUrl> publishesPresenceTos() const {
-        QList<QUrl> value;
-        foreach(const QVariant& v, property(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#publishesPresenceTo", QUrl::StrictMode)))
-            value << v.value<QUrl>();
+    QString imStatusMessage() const {
+        QString value;
+        if(contains(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#imStatusMessage", QUrl::StrictMode)))
+            value = property(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#imStatusMessage", QUrl::StrictMode)).first().value<QString>();
         return value;
     }
 
     /**
-     * Set property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#publishesPresenceTo. 
-     * Indicates that this IMAccount publishes its presence information 
-     * to the other IMAccount. 
+     * Set property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#imStatusMessage. 
+     * A feature common in most IM systems. A message left by the user 
+     * for all his/her contacts to see. 
      */
-    void setPublishesPresenceTos(const QList<QUrl>& value) {
+    void setImStatusMessage(const QString& value) {
         QVariantList values;
-        foreach(const QUrl& v, value)
-            values << v;
-        setProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#publishesPresenceTo", QUrl::StrictMode), values);
+        values << value;
+        setProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#imStatusMessage", QUrl::StrictMode), values);
     }
 
     /**
-     * Add value to property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#publishesPresenceTo. 
-     * Indicates that this IMAccount publishes its presence information 
-     * to the other IMAccount. 
+     * Add value to property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#imStatusMessage. 
+     * A feature common in most IM systems. A message left by the user 
+     * for all his/her contacts to see. 
      */
-    void addPublishesPresenceTo(const QUrl& value) {
-        addProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#publishesPresenceTo", QUrl::StrictMode), value);
+    void addImStatusMessage(const QString& value) {
+        addProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#imStatusMessage", QUrl::StrictMode), value);
     }
 
     /**
@@ -384,40 +384,41 @@ public:
     }
 
     /**
-     * Get property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#imID. 
-     * Identifier of the IM account. Examples of such identifier might 
-     * include ICQ UINs, Jabber IDs, Skype names etc. 
+     * Get property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#requestedPresenceSubscriptionTo. 
+     * Indicates that this IMAccount has requested a subscription 
+     * to the presence information of the other IMAccount. 
      */
-    QStringList imIDs() const {
-        QStringList value;
-        foreach(const QVariant& v, property(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#imID", QUrl::StrictMode)))
-            value << v.value<QString>();
+    QList<QUrl> requestedPresenceSubscriptionTos() const {
+        QList<QUrl> value;
+        foreach(const QVariant& v, property(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#requestedPresenceSubscriptionTo", QUrl::StrictMode)))
+            value << v.value<QUrl>();
         return value;
     }
 
     /**
-     * Set property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#imID. 
-     * Identifier of the IM account. Examples of such identifier might 
-     * include ICQ UINs, Jabber IDs, Skype names etc. 
+     * Set property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#requestedPresenceSubscriptionTo. 
+     * Indicates that this IMAccount has requested a subscription 
+     * to the presence information of the other IMAccount. 
      */
-    void setImIDs(const QStringList& value) {
+    void setRequestedPresenceSubscriptionTos(const QList<QUrl>& value) {
         QVariantList values;
-        foreach(const QString& v, value)
+        foreach(const QUrl& v, value)
             values << v;
-        setProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#imID", QUrl::StrictMode), values);
+        setProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#requestedPresenceSubscriptionTo", QUrl::StrictMode), values);
     }
 
     /**
-     * Add value to property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#imID. 
-     * Identifier of the IM account. Examples of such identifier might 
-     * include ICQ UINs, Jabber IDs, Skype names etc. 
+     * Add value to property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#requestedPresenceSubscriptionTo. 
+     * Indicates that this IMAccount has requested a subscription 
+     * to the presence information of the other IMAccount. 
      */
-    void addImID(const QString& value) {
-        addProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#imID", QUrl::StrictMode), value);
+    void addRequestedPresenceSubscriptionTo(const QUrl& value) {
+        addProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#requestedPresenceSubscriptionTo", QUrl::StrictMode), value);
     }
 
 protected:
-    IMAccount(const QUrl& uri, const QUrl& type)      : SimpleResource(uri), NCO::ContactMedium(uri, type) {
+    IMAccount(const QUrl& uri, const QUrl& type)
+      : SimpleResource(uri), NCO::ContactMedium(uri, type) {
     }
     IMAccount(const SimpleResource& res, const QUrl& type)
       : SimpleResource(res), NCO::ContactMedium(res, type) {
