@@ -8,9 +8,9 @@
 #include <QtCore/QTime>
 #include <QtCore/QDateTime>
 
-#include <nepomuk/simpleresource.h>
+#include <nepomuk2/simpleresource.h>
 
-namespace Nepomuk {
+namespace Nepomuk2 {
 namespace NCO {
 /**
  * A role played by a contact. Contacts that denote people, can 
@@ -19,7 +19,7 @@ namespace NCO {
  * usually have one role. Each role can introduce additional contact 
  * media. 
  */
-class Role : public virtual Nepomuk::SimpleResource
+class Role : public virtual Nepomuk2::SimpleResource
 {
 public:
     Role(const QUrl& uri = QUrl())
@@ -38,44 +38,6 @@ public:
         return *this;
     }
 
-    /**
-     * Get property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#end. 
-     * End datetime for the role, such as: the datetime of leaving a 
-     * project or organization, datetime of ending employment, datetime 
-     * of divorce. If absent or set to a date in the future, the role is 
-     * currently active. 
-     */
-    QDateTime end() const {
-        QDateTime value;
-        if(contains(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#end", QUrl::StrictMode)))
-            value = property(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#end", QUrl::StrictMode)).first().value<QDateTime>();
-        return value;
-    }
-
-    /**
-     * Set property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#end. 
-     * End datetime for the role, such as: the datetime of leaving a 
-     * project or organization, datetime of ending employment, datetime 
-     * of divorce. If absent or set to a date in the future, the role is 
-     * currently active. 
-     */
-    void setEnd(const QDateTime& value) {
-        QVariantList values;
-        values << value;
-        setProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#end", QUrl::StrictMode), values);
-    }
-
-    /**
-     * Add value to property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#end. 
-     * End datetime for the role, such as: the datetime of leaving a 
-     * project or organization, datetime of ending employment, datetime 
-     * of divorce. If absent or set to a date in the future, the role is 
-     * currently active. 
-     */
-    void addEnd(const QDateTime& value) {
-        addProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#end", QUrl::StrictMode), value);
-    }
-
     /**
      * Get property http://www.semanticdesktop.org/ontologies/2007/01/19/nie#disclaimer. 
      * A disclaimer 
@@ -263,6 +225,39 @@ public:
         addProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nfo#sideChannels", QUrl::StrictMode), value);
     }
 
+    /**
+     * Get property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#hasPostalAddress. 
+     * The default Address for a Contact. An equivalent of the 'ADR' 
+     * property as defined in RFC 2426 Sec. 3.2.1. 
+     */
+    QList<QUrl> postalAddresses() const {
+        QList<QUrl> value;
+        foreach(const QVariant& v, property(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#hasPostalAddress", QUrl::StrictMode)))
+            value << v.value<QUrl>();
+        return value;
+    }
+
+    /**
+     * Set property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#hasPostalAddress. 
+     * The default Address for a Contact. An equivalent of the 'ADR' 
+     * property as defined in RFC 2426 Sec. 3.2.1. 
+     */
+    void setPostalAddresses(const QList<QUrl>& value) {
+        QVariantList values;
+        foreach(const QUrl& v, value)
+            values << v;
+        setProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#hasPostalAddress", QUrl::StrictMode), values);
+    }
+
+    /**
+     * Add value to property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#hasPostalAddress. 
+     * The default Address for a Contact. An equivalent of the 'ADR' 
+     * property as defined in RFC 2426 Sec. 3.2.1. 
+     */
+    void addPostalAddress(const QUrl& value) {
+        addProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#hasPostalAddress", QUrl::StrictMode), value);
+    }
+
     /**
      * Get property http://www.semanticdesktop.org/ontologies/2007/01/19/nie#depends. 
      * Dependency relation. A piece of content depends on another 
@@ -394,39 +389,6 @@ public:
         addProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nfo#lfeChannels", QUrl::StrictMode), value);
     }
 
-    /**
-     * Get property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#hasPostalAddress. 
-     * The default Address for a Contact. An equivalent of the 'ADR' 
-     * property as defined in RFC 2426 Sec. 3.2.1. 
-     */
-    QList<QUrl> postalAddresses() const {
-        QList<QUrl> value;
-        foreach(const QVariant& v, property(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#hasPostalAddress", QUrl::StrictMode)))
-            value << v.value<QUrl>();
-        return value;
-    }
-
-    /**
-     * Set property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#hasPostalAddress. 
-     * The default Address for a Contact. An equivalent of the 'ADR' 
-     * property as defined in RFC 2426 Sec. 3.2.1. 
-     */
-    void setPostalAddresses(const QList<QUrl>& value) {
-        QVariantList values;
-        foreach(const QUrl& v, value)
-            values << v;
-        setProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#hasPostalAddress", QUrl::StrictMode), values);
-    }
-
-    /**
-     * Add value to property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#hasPostalAddress. 
-     * The default Address for a Contact. An equivalent of the 'ADR' 
-     * property as defined in RFC 2426 Sec. 3.2.1. 
-     */
-    void addPostalAddress(const QUrl& value) {
-        addProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#hasPostalAddress", QUrl::StrictMode), value);
-    }
-
     /**
      * Get property http://www.semanticdesktop.org/ontologies/2007/01/19/nie#license. 
      * Terms and intellectual property rights licensing conditions. 
@@ -549,6 +511,44 @@ public:
         addProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/01/19/nie#copyright", QUrl::StrictMode), value);
     }
 
+    /**
+     * Get property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#end. 
+     * End datetime for the role, such as: the datetime of leaving a 
+     * project or organization, datetime of ending employment, datetime 
+     * of divorce. If absent or set to a date in the future, the role is 
+     * currently active. 
+     */
+    QDateTime end() const {
+        QDateTime value;
+        if(contains(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#end", QUrl::StrictMode)))
+            value = property(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#end", QUrl::StrictMode)).first().value<QDateTime>();
+        return value;
+    }
+
+    /**
+     * Set property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#end. 
+     * End datetime for the role, such as: the datetime of leaving a 
+     * project or organization, datetime of ending employment, datetime 
+     * of divorce. If absent or set to a date in the future, the role is 
+     * currently active. 
+     */
+    void setEnd(const QDateTime& value) {
+        QVariantList values;
+        values << value;
+        setProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#end", QUrl::StrictMode), values);
+    }
+
+    /**
+     * Add value to property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#end. 
+     * End datetime for the role, such as: the datetime of leaving a 
+     * project or organization, datetime of ending employment, datetime 
+     * of divorce. If absent or set to a date in the future, the role is 
+     * currently active. 
+     */
+    void addEnd(const QDateTime& value) {
+        addProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#end", QUrl::StrictMode), value);
+    }
+
     /**
      * Get property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#url. 
      * A uniform resource locator associated with the given role of 
@@ -615,41 +615,6 @@ public:
         addProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#websiteUrl", QUrl::StrictMode), value);
     }
 
-    /**
-     * Get property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#start. 
-     * Start datetime for the role, such as: the datetime of joining 
-     * a project or organization, datetime of starting employment, 
-     * datetime of marriage 
-     */
-    QDateTime start() const {
-        QDateTime value;
-        if(contains(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#start", QUrl::StrictMode)))
-            value = property(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#start", QUrl::StrictMode)).first().value<QDateTime>();
-        return value;
-    }
-
-    /**
-     * Set property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#start. 
-     * Start datetime for the role, such as: the datetime of joining 
-     * a project or organization, datetime of starting employment, 
-     * datetime of marriage 
-     */
-    void setStart(const QDateTime& value) {
-        QVariantList values;
-        values << value;
-        setProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#start", QUrl::StrictMode), values);
-    }
-
-    /**
-     * Add value to property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#start. 
-     * Start datetime for the role, such as: the datetime of joining 
-     * a project or organization, datetime of starting employment, 
-     * datetime of marriage 
-     */
-    void addStart(const QDateTime& value) {
-        addProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#start", QUrl::StrictMode), value);
-    }
-
     /**
      * Get property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#foafUrl. 
      * The URL of the FOAF file. 
@@ -713,8 +678,44 @@ public:
         addProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/01/19/nie#licenseType", QUrl::StrictMode), value);
     }
 
+    /**
+     * Get property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#start. 
+     * Start datetime for the role, such as: the datetime of joining 
+     * a project or organization, datetime of starting employment, 
+     * datetime of marriage 
+     */
+    QDateTime start() const {
+        QDateTime value;
+        if(contains(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#start", QUrl::StrictMode)))
+            value = property(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#start", QUrl::StrictMode)).first().value<QDateTime>();
+        return value;
+    }
+
+    /**
+     * Set property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#start. 
+     * Start datetime for the role, such as: the datetime of joining 
+     * a project or organization, datetime of starting employment, 
+     * datetime of marriage 
+     */
+    void setStart(const QDateTime& value) {
+        QVariantList values;
+        values << value;
+        setProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#start", QUrl::StrictMode), values);
+    }
+
+    /**
+     * Add value to property http://www.semanticdesktop.org/ontologies/2007/03/22/nco#start. 
+     * Start datetime for the role, such as: the datetime of joining 
+     * a project or organization, datetime of starting employment, 
+     * datetime of marriage 
+     */
+    void addStart(const QDateTime& value) {
+        addProperty(QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/03/22/nco#start", QUrl::StrictMode), value);
+    }
+
 protected:
-    Role(const QUrl& uri, const QUrl& type)      : SimpleResource(uri) {
+    Role(const QUrl& uri, const QUrl& type)
+      : SimpleResource(uri) {
         addType(type);
     }
     Role(const SimpleResource& res, const QUrl& type)
